"""user module

 ver 1.3
 by Krtyski/e-Gadget

 Functions:
 ---------
 grp_color()
 circle()
 line()
 locate()
 
"""
from math import *
from casioplot import *

def grp_color(color=1):
 """Convert color parameter to rgb in tuple

 version 1.0

 parameters:
 ----------
  color: code, name,      rgb
         0    'white'   (255,255,255)
         1    'black'   (0,    0,  0)
         2    'blue'    (0,    0,255)
         3    'red'     (255,  0,  0)
         4    'magenta' (255,  0,255)
         5    'green'   (0,  255,  0)
         6    'cyan'    (0,  255,255)
         7    'yellow'  (255,255,  0)
    default:1 'black'   (0,0,0)

 Returns:
 -------
  tuple:(r,g,b)
 """
 #set rgb from argument(color)
 rgb=[(255,255,255),(0,0,0),(0,0,255),(255,0,0),(255,0,255),(0,255,0),(0,255,255),(255,255,0)]
 c_name=['white','black','blue','red','magenta','green','cyan','yellow']

 if type(color) is int:
  if 0<=color<=7:
   c_rgb=rgb[color]
  else:
   c_rgb=(0,0,0)
 elif type(color) is str:
  if color in c_name:
   c_rgb=rgb[c_name.index(color)]
  else:
   c_rgb=(0,0,0)
 elif type(color) is tuple:
  c_rgb=color
 else: #fail-proof
  c_rgb=(0,0,0)
 
 return c_rgb


def circle(x,y,r,color=1,show=1):
 """Draw circle around (x,y) with radius r

 version 1.0

 Parameters:
 ----------
 x,y:int
  center coordinate
 r:float
  radius
 color:
  compatible with grp_color()
 show:0 or 1 (int/bool)
  0: don't transfer to screen
  1: transfer to screen
  default:1

 Returns:
 -------
 None
 """
 rgb=grp_color(color)
 p=r*2406/383 #number of plots
 a=2*pi/p #angle step in radian
 for i in range(p):
  px=x+r*cos(i*a)
  if px<0 or px>383:
   continue
  py=y+r*sin(i*a)
  if py<0 or py>191:
   continue
  set_pixel(int(px),int(py),rgb)
  if show: #data transfer to screen
   show_screen()


def line(x1,y1,x2,y2,color=1,show=1):
 """Draw line from (x1,y1) to (x2,y2)
 
 version 1.2

 Parameters:
 ----------
 x1,y1:int
  starting coordinate
 x2,y2:int
  ending coordinate
 color:
  compatible with grp_color()
 show:0 or 1 (int/bool)
  0: don't transfer to screen
  1: transfer to screen
  default:1

 Returns:   
 ------
 None
 """
 rgb=grp_color(color)
 dx=x2-x1;dy=y2-y1
 if dx==0 and dy==0: #avoid division by 0 error
   set_pixel(x1,y1,rgb)
   return
 if abs(dx)>abs(dy):
  if dx: #when dx is not 0
   k=int(dx/abs(dx)) #k=1 or -1
   slope=dy/dx
   for x in range(0,dx,k):
    set_pixel(x1+x,y1+int(x*slope),rgb)
 else:
  if dy: #when dy is not 0
   k=int(dy/abs(dy)) #k=1 or -1
   slope=dx/dy
   for y in range(0,dy,k):
    set_pixel(x1+int(y*slope),y1+y,rgb)

 if show:
  show_screen()


def locate(column,row,obj,color=1,size='m',show=1):
 """Locate number or string on graphic screen
 
 version 1.0

 Parameters:
 ----------
 column:0-47, row:0-17 (small  font)
        0-31,     0-11 (medium font)
        0-23,     0-7  (large  font)
 obj:number(int or float)
      string(str)
 size:'s'
      'm'
      'l'
      default:'m'
 color:
      compatible with grp_color()
 show:0 or 1 (int/bool)
      0: don't transfer to screen
      1: transfer to screen
      default:1

 Returns:
 -------
 None
 """
 #set fontsize & pitch
 #from 4th argument(size)
 dx={'s':8,'m':12,'l':16}
 dy={'s':12,'m':16,'l':24}
 sz={'s':'small','m':'medium','l':'large'}
 
 #data transfer to VRAM
 draw_string(column*dx[size],row*dy[size],str(obj),grp_color(color),sz[size])
 
 if show: #data transfer to screen
  show_screen() 
